# Changelog

## [Unreleased](https://github.com/oscarmcm/django-places/tree/HEAD)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v3.1.0...HEAD)

**Implemented enhancements:**

- Update fields.py for Django 3.0 [\#24](https://github.com/oscarmcm/django-places/pull/24) ([dryan](https://github.com/dryan))

**Closed issues:**

-  Deprecated Field.\_get\_val\_from\_obj\(\) [\#25](https://github.com/oscarmcm/django-places/issues/25)

## [v3.1.0](https://github.com/oscarmcm/django-places/tree/v3.1.0) (2018-10-30)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v3.0.0...v3.1.0)

**Implemented enhancements:**

- Support marker options and set marker as draggable [\#22](https://github.com/oscarmcm/django-places/pull/22) ([oscarmcm](https://github.com/oscarmcm))

**Fixed bugs:**

- Empty Map in admin [\#16](https://github.com/oscarmcm/django-places/issues/16)

## [v3.0.0](https://github.com/oscarmcm/django-places/tree/v3.0.0) (2018-10-29)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v2.0.0...v3.0.0)

**Implemented enhancements:**

- Load map-options settings [\#21](https://github.com/oscarmcm/django-places/pull/21) ([oscarmcm](https://github.com/oscarmcm))
- Add support for inline admin [\#20](https://github.com/oscarmcm/django-places/pull/20) ([oscarmcm](https://github.com/oscarmcm))

**Fixed bugs:**

- Multiple PlacesField\(\) Objects declaration in one Model clones data from one Object to the other. [\#14](https://github.com/oscarmcm/django-places/issues/14)
- Remove jquery geocomplete [\#19](https://github.com/oscarmcm/django-places/pull/19) ([oscarmcm](https://github.com/oscarmcm))

## [v2.0.0](https://github.com/oscarmcm/django-places/tree/v2.0.0) (2017-09-10)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.1.4...v2.0.0)

**Implemented enhancements:**

- Update for django 1.11 [\#12](https://github.com/oscarmcm/django-places/pull/12) ([pavillet](https://github.com/pavillet))

**Fixed bugs:**

- Django 1.11 not render widget [\#9](https://github.com/oscarmcm/django-places/issues/9)

## [v1.1.4](https://github.com/oscarmcm/django-places/tree/v1.1.4) (2017-05-08)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.1.3...v1.1.4)

**Fixed bugs:**

- undefined name Location [\#10](https://github.com/oscarmcm/django-places/issues/10)

## [v1.1.3](https://github.com/oscarmcm/django-places/tree/v1.1.3) (2017-05-07)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.1.2...v1.1.3)

**Fixed bugs:**

- Kwargs problem [\#8](https://github.com/oscarmcm/django-places/issues/8)
- Problems with djplaces [\#6](https://github.com/oscarmcm/django-places/issues/6)
- i18n support [\#3](https://github.com/oscarmcm/django-places/issues/3)

## [v1.1.2](https://github.com/oscarmcm/django-places/tree/v1.1.2) (2017-05-07)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.1.1...v1.1.2)

## [v1.1.1](https://github.com/oscarmcm/django-places/tree/v1.1.1) (2017-01-22)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.1.0...v1.1.1)

## [v1.1.0](https://github.com/oscarmcm/django-places/tree/v1.1.0) (2017-01-09)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.5...v1.1.0)

## [v1.0.5](https://github.com/oscarmcm/django-places/tree/v1.0.5) (2016-07-26)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.4...v1.0.5)

**Implemented enhancements:**

- Add own jquery to avoid conflicts and be able to used in admin and templates [\#5](https://github.com/oscarmcm/django-places/pull/5) ([darwing1210](https://github.com/darwing1210))

## [v1.0.4](https://github.com/oscarmcm/django-places/tree/v1.0.4) (2016-07-20)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.3...v1.0.4)

## [v1.0.3](https://github.com/oscarmcm/django-places/tree/v1.0.3) (2016-06-01)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.2...v1.0.3)

## [v1.0.2](https://github.com/oscarmcm/django-places/tree/v1.0.2) (2016-05-12)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.1...v1.0.2)

## [v1.0.1](https://github.com/oscarmcm/django-places/tree/v1.0.1) (2016-05-12)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.0...v1.0.1)

**Fixed bugs:**

- Geocomplete is not a function [\#1](https://github.com/oscarmcm/django-places/issues/1)

**Merged pull requests:**

- Fixes \#1 Geocomplete is not a function [\#2](https://github.com/oscarmcm/django-places/pull/2) ([oscarmcm](https://github.com/oscarmcm))

## [v1.0.0](https://github.com/oscarmcm/django-places/tree/v1.0.0) (2016-04-28)

[Full Changelog](https://github.com/oscarmcm/django-places/compare/76c5eebb54bbffa7840162934b0086ce96a9eade...v1.0.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
